









#!/bin/bash
#
# Vagrant provisionning script to use with VM gate
# 
# @author: metrot@math.univ-poitiers.fr
# @version: 0.9


# NO Debconf questions during packages installation
export DEBIAN_FRONTEND='noninteractive'

#
# STEP 1 :  Fix hostname and static name résolution
###
echo gate > /etc/hostname
hostname gate


cat <<EOF > /etc/hosts
127.0.0.1       localhost.localdomain           localhost
10.0.2.2        vagrant.virtualbox              vagrant

#172.16.20.5     gate.vbox.tp                    gate

172.16.20.5     gate.vbox.tp            gate
172.16.20.11	kdc.vbox.tp		kdc
172.16.20.12	web.vbox.tp		web
172.16.20.13	filer.vbox.tp		filer
172.16.20.14	ad.vbox.tp		ad
172.16.20.15	kdc2.vbox.tp		kdc2
172.16.20.21	clinux.vbox.tp		clinux
172.16.20.22	cwin.vbox.tp		cwin
172.16.20.23	cfedora.vbox.tp		cfedora

172.16.1.10	www.loire.tp wiki.loire.tp

# The following lines are desirable for IPv6 capable hosts
::1     localhost ip6-localhost ip6-loopback
ff02::1 ip6-allnodes
ff02::2 ip6-allroute
EOF



#
# STEP 2 : Install bind and configure DNS 
###
apt-get install -y bind9 bind9utils bind9-doc


cat <<EOF > /etc/bind/named.conf.options
options {
        directory "/var/cache/bind";

        // If there is a firewall between you and nameservers you want
        // to talk to, you may need to fix the firewall to allow multiple
        // ports to talk.  See http://www.kb.cert.org/vuls/id/800113

        // If your ISP provided one or more IP addresses for stable 
        // nameservers, you probably want to use them as forwarders.  
        // Uncomment the following block, and insert the addresses replacing 
        // the all-0's placeholder.

        forwarders {
              172.16.1.10;
        };
        //========================================================================
        // If BIND logs error messages about the root key being expired,
        // you will need to update your keys.  See https://www.isc.org/bind-keys
        //========================================================================
        dnssec-validation auto;

        auth-nxdomain no;    # conform to RFC1035
        listen-on-v6 { none; };
};
EOF
 

cat <<EOF > /etc/bind/db.vbox.tp
; Zone vbox.tp
\$TTL  604800
@       IN      SOA     vbox.tp. admin.vbox.tp. (
                20140122        ; Serial
                604800          ; Refresh
                86400           ; Retry
                2419200         ; Expire
                604800  )       ; Negative cache TTL

@       IN      NS      gate

gate    IN      A       172.16.20.5
kdc     IN      A       172.16.20.11
web     IN      A       172.16.20.12
filer   IN      A       172.16.20.13
ad      IN      A       172.16.20.14
kdc2	IN	A	172.16.20.15
clinux  IN      A       172.16.20.21
cwin    IN      A       172.16.20.22
cfedora IN      A       172.16.20.23

intranet IN     CNAME   web

EOF
 

cat <<EOF > /etc/bind/db.172.16.20
; Zone inverse pour 172.16.20.0/24
\$TTL    604800
@       IN      SOA     gate.vbox.tp.    admin.vbox.tp. (
                20140122        ; Serial
                604800          ; Refresh
                86400           ; Retry
                2419200         ; Expire
                604800 )        ; Negative Cache TTL

        IN      NS      gate.vbox.tp.

5       IN      PTR     gate.vbox.tp.
11      IN      PTR     kdc.vbox.tp.
12      IN      PTR     web.vbox.tp.
13      IN      PTR     filer.vbox.tp.
14      IN      PTR     ad.vbox.tp.
15	IN	PTR	kdc2.vbox.tp.
21      IN      PTR     clinux.vbox.tp.
22      IN      PTR     cwin.vbox.tp.
23      IN      PTR     cfedora.vbox.tp.

EOF
 

cat <<EOF > /etc/bind/named.conf.vbox
zone "vbox.tp" {
        type master;
        file "/etc/bind/db.vbox.tp";
};

zone "20.16.172.in-addr.arpa" {
        type master;
        file "/etc/bind/db.172.16.20";
};

// TP zone
// zone "loire.tp" {
//        type forward;
//        forwarders {
//            172.16.1.10;
//        };
//};

EOF
 

cat <<EOF > /etc/bind/named.conf
// This is the primary configuration file for the BIND DNS server named.
//
// Please read /usr/share/doc/bind9/README.Debian.gz for information on the 
// structure of BIND configuration files in Debian, *BEFORE* you customize 
// this configuration file.
//
// If you are just adding zones, please do that in /etc/bind/named.conf.local

include "/etc/bind/named.conf.options";
include "/etc/bind/named.conf.local";
include "/etc/bind/named.conf.default-zones";
include "/etc/bind/named.conf.vbox";

EOF
 

service bind9 restart


#
# STEP 3 : Install and populate LDAP directory
###
apt-get install -y slapd ldap-utils

# Fichiers certificats

cat <<EOF > /etc/ldap/slapd.key
-----BEGIN PRIVATE KEY-----
MIIEvAIBADANBgkqhkiG9w0BAQEFAASCBKYwggSiAgEAAoIBAQDk7C3f/IBQEo7T
nKh6NwUUGqQVf0t2osVD5WTTNPGuNUXRmZgfLU0Sho1Pzd5JQe8OFizEEvahBgGu
S4Zq2YCOgGEK8jYyKo1+pVgtoN+2A3sOA5d/gvHmN2fi1hfbTYf8EjPNU82RlpVL
LfN+ZGQ8snS9DCY8S/ymrw+6YSRoRQ+NfkKxN1JMPMRpVlm2ePaVlZ4j5JYmd9eb
v1/oQbsZFTvhu/HcZtxf53MPUUtVD9plTcNjbkdVmpO21ckuRLKPId0UQdFkLb00
aYkJWOrwZiev5zUVUeWLO9mut3izvZ9ikXZYbgBPxq2DYWH9rl1VBG7KvSmflVHR
vxNq/ssfAgMBAAECggEAVG74DKEpAl+V5l7llQ4uBVg+JN+qibtHXt+A7JWefk6P
zdsEzJr8zlRqUoDv970l2uA66qbD6Gg6vnqEvWwzilu3bz4e1ynyvj9l4o5vdMab
4HNasWEur2bIHlYwvmY+Pa7JBHZgX85WikAMixWkEu8PN5r/j0XHjgMLngauUvZT
TlH+JTm6H85mlUfN5VuaKAq7qHrSy5rgW3tOvYf7IeaINIbxJXGbOVyI7BRldQD9
ykiRN5Jktw/stoCzJ8uaiaJmKEGCH+D5HS/i++vuRcLNL8PSmuvtRRlXeEatuAWC
pcfzc6BKHEAkiRBudHVYrUAM9RtsZNxH7y8F98VcYQKBgQDyOwRoVBmIIF0m/6kC
+OW616v90wqErr1cGOZf0Ed7YTAJilSeIvu0udRA/UDPUkF46bHZ97JKOZDnutJX
muSGgmwKoWcFCAFkbGuT5oyzjCnsTyItdyba1u0aoNpanXlxWXZ4OkC2oNsqpgxn
3OGneLpMq8uBdlZM6DgQFOhxRQKBgQDx74CKmjSLq2xR1ykMNiq6lKQ9HCA6qUaI
//3gBBSXeYTs6xcdtRGB73NLDupiPUicauScsymfDFB2fxy3gwljRylOVR6N0UY4
WcCy4dMDepdzZaxOltrYtH3j72yfWbdr5KVLhQmD15CMoz3vyDh4UmPd3Jlw6qs0
vuvTLqeHEwKBgCURbPo+LG4NbdPi+c0vo5A1IufD3O8zAl1Onip5aAb0d3JuTcap
WdVtPpL3bmyLjONg98uAQTNknc0oZLntRR1kZf42dtppQDVK9id693sebufvsC4+
9p40l7IkfWWyhXwYEa4SVAbelMtw/6MBRTLoobHL9GeKYWiBfNrRKET1AoGAdksQ
orR7dL9Am1OEsn/ZrJj5JRgXehdCccIZM+tK1jWIlP7tsozSHqIh0VVdrOMiGbj6
RtQjSa0PuqC0PdZIRM6Kl85uvhDRMMRRwCVCs7TBUJ8p/NMt9j9qPoTWq6OGV67Y
U3CdEmXYO6uloRRY6BwA0H4IWHmldIjVbdCmARkCgYAgKcLR7fgLuqzxFetvcL5r
MwOlDrwwUP/j5HnNiyfvkBazrzwwXSqxb5n+PByDOKRkL8ZIPOYjfxbV8aHzeT1+
aUZUu9G2ayimg2QI00oaGsXJBw1WXRvBd5zxsfnhEbF6UhgaaVwo5Qw4dX06FtV4
B+V7DRmJdZi+b9LhvDDUTQ==
-----END PRIVATE KEY-----

EOF


cat <<EOF > /etc/ldap/slapd.crt
-----BEGIN CERTIFICATE-----
MIID+zCCAuOgAwIBAgIJALcXA2a7TDm9MA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD
VQQGEwJmcjEZMBcGA1UECAwQUGF5cyBkZSBsYSBMb2lyZTEPMA0GA1UEBwwGQW5n
ZXJzMRUwEwYDVQQKDAxNYXRocmljZSBBTkYxDDAKBgNVBAsMA0FORjEVMBMGA1UE
AwwMZ2F0ZS52Ym94LnRwMRwwGgYJKoZIhvcNAQkBFg1hZG1pbkB2Ym94LnRwMB4X
DTE0MDgwNjA4NDcwNloXDTE1MDgwNjA4NDcwNlowgZMxCzAJBgNVBAYTAmZyMRkw
FwYDVQQIDBBQYXlzIGRlIGxhIExvaXJlMQ8wDQYDVQQHDAZBbmdlcnMxFTATBgNV
BAoMDE1hdGhyaWNlIEFORjEMMAoGA1UECwwDQU5GMRUwEwYDVQQDDAxnYXRlLnZi
b3gudHAxHDAaBgkqhkiG9w0BCQEWDWFkbWluQHZib3gudHAwggEiMA0GCSqGSIb3
DQEBAQUAA4IBDwAwggEKAoIBAQDk7C3f/IBQEo7TnKh6NwUUGqQVf0t2osVD5WTT
NPGuNUXRmZgfLU0Sho1Pzd5JQe8OFizEEvahBgGuS4Zq2YCOgGEK8jYyKo1+pVgt
oN+2A3sOA5d/gvHmN2fi1hfbTYf8EjPNU82RlpVLLfN+ZGQ8snS9DCY8S/ymrw+6
YSRoRQ+NfkKxN1JMPMRpVlm2ePaVlZ4j5JYmd9ebv1/oQbsZFTvhu/HcZtxf53MP
UUtVD9plTcNjbkdVmpO21ckuRLKPId0UQdFkLb00aYkJWOrwZiev5zUVUeWLO9mu
t3izvZ9ikXZYbgBPxq2DYWH9rl1VBG7KvSmflVHRvxNq/ssfAgMBAAGjUDBOMB0G
A1UdDgQWBBSofhql2uPlQKHB5UiOY9Jdyf6QyzAfBgNVHSMEGDAWgBSofhql2uPl
QKHB5UiOY9Jdyf6QyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBP
FSoiQIOk9q5hlcLm4lOKvWRVTYaXRs+gtqy7zjdpYdAy2SRmpFSI7IWrPrGwCow4
v4XjV+294aJe8REgNLzNDVgzaIsthgWXj1B2Q6SF/oxr8rUsgTGV13S0UZS20dZj
qa1PsnaE1F4nHv6g31Xo8fva9k7XLXV4cJ+kCcYxB5KB4n5EClUgiFIzJdguvZ3S
CNADFUnYS642bMDduFFfRLRNKLJq7YR/1ZsS+YA5ZHbDPl5t/sndW4KpT7ROJm4h
ebhIa4g0Ymy83zAaD/lRXL98H7FPmqRV1QB6MBDF+BygfbGl50dm6VZuJMEiL0Om
kkdWfAmIogXGET3pSF7b
-----END CERTIFICATE-----

EOF

chown root.openldap /etc/ldap/slapd.key /etc/ldap/slapd.crt
chmod 640 /etc/ldap/slapd.key
chmod 644 /etc/ldap/slapd.crt


# Get current root DN
RootDN=$(grep -i ^olcrootdn: /etc/ldap/slapd.d/cn\=config/olcDatabase\=\{1\}hdb.ldif | cut -d ' ' -f 2)
if [ -z "$RootDN" ]; then
    echo "$0: unable to get predefined root DN" > /dev/stderr
    exit 1
fi

# Change root password to 'lda@p'
RootPW='ld@p'
cat <<EOF > /tmp/changerootpw.ldif
dn: olcDatabase={1}hdb,cn=config
changetype: modify
replace: olcRootPW
olcRootPw: {SSHA}OcXIbGaqh8fMlkOMRNiY2rfwUC2eRcVC
EOF
ldapmodify -QY EXTERNAL -H ldapi:/// -f /tmp/changerootpw.ldif


# Remove existing entry in database
echo -n "Removing existing entry in database..." 
slapcat | grep '^dn: ' | cut -d ' ' -f 2 | sort | ldapdelete -x -H ldap://127.0.0.1 -D $RootDN  -w $RootPW
if [ $? -eq 0 ]; then
  echo Done
else
  echo Failed
fi

# Change defaut DSE, root DN  and ACL
# Root DN set to cn=admin,dc=vbox,dc=fr
# Root password set to ld@p
cat <<EOF > /tmp/changeroot.ldif
dn: olcDatabase={1}hdb,cn=config
changetype: modify
replace: olcSuffix
olcSuffix: dc=vbox, dc=tp
-
replace: OlcAccess
OlcAccess: {0}to attrs=userPassword,shadowLastChange 
  by self write 
  by anonymous auth 
  by dn="cn=admin,dc=vbox,dc=tp" write 
  by * none
olcAccess: {1}to dn.base="" 
  by * read
olcAccess: {2}to * 
  by self write 
  by dn="cn=admin,dc=vbox,dc=tp" write 
  by * read
-
replace: olcRootDN
olcRootDN: cn=admin,dc=vbox,dc=tp
-
replace: olcRootPW
olcRootPw: {SSHA}OcXIbGaqh8fMlkOMRNiY2rfwUC2eRcVC
EOF
ldapmodify -QY EXTERNAL -H ldapi:/// -f /tmp/changeroot.ldif

# Create root object in directory
cat <<EOF > /tmp/init-dit.ldif
dn: dc=vbox,dc=tp
objectClass: top
objectClass: dcObject
objectClass: organization
o: vbox.tp
dc: vbox

dn: cn=admin,dc=vbox,dc=tp
objectClass: simpleSecurityObject
objectClass: organizationalRole
cn: admin
description: LDAP administrator
userPassword: {SSHA}OcXIbGaqh8fMlkOMRNiY2rfwUC2eRcVC

dn: ou=people,dc=vbox,dc=tp
ou: people
objectClass: organizationalUnit

dn: ou=groups,dc=vbox,dc=tp
ou: groups
objectClass: organizationalUnit
EOF
ldapadd -x -H ldap://127.0.0.1 -D "cn=admin,dc=vbox,dc=tp" -w $RootPW -f /tmp/init-dit.ldif

# Changing loglevel
cat <<EOF > /tmp/loglevel.ldif
dn: cn=config
changetype: modify
replace: olcLogLevel
olcLogLevel: 256
EOF
ldapmodify -QY EXTERNAL -H ldapi:/// -f /tmp/loglevel.ldif

# Adding overlay
cat <<EOF > /tmp/module.ldif
dn: cn=module{0},cn=config
changetype: modify
add: olcModuleLoad
olcModuleLoad: {1}memberof
EOF
ldapmodify -QY EXTERNAL -H ldapi:/// -f /tmp/module.ldif
cat <<EOF > /tmp/overlay-memberof.ldif
dn: olcOverlay=memberof,olcDatabase={1}hdb,cn=config
changetype: add
objectClass: olcOverlayConfig
olcOverlay: memberof
EOF
ldapmodify -QY EXTERNAL -H ldapi:/// -f /tmp/overlay-memberof.ldif
service slapd restart

# Enable SSL
cat <<EOF > /tmp/enable-tls.ldif
dn: cn=config
changetype: modify
replace: olcTLSCertificateFile
olcTLSCertificateFile: /etc/ldap/slapd.crt
-
replace: olcTLSCertificateKeyFile
olcTLSCertificateKeyFile: /etc/ldap/slapd.key
-
replace: olcTLSVerifyClient
olcTLSVerifyClient: never
-
EOF
ldapmodify -QY EXTERNAL -H ldapi:/// -f /tmp/enable-tls.ldif

# Restart slapd service
sed -ie 's|^SLAPD_SERVICES=.*|SLAPD_SERVICES="ldapi:/// ldap:/// ldaps:///"|' /etc/default/slapd
service slapd restart

# Remplissage de l'annuaire

cat <<EOF > /tmp/users.ldif
dn: uid=anomusu,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Agtpre.Nomusu
sn: Agtnom
givenName: Agtpre
uid: anomusu
uidNumber: 1001
gidNumber: 300
homeDirectory: /nfs/home/anomusu
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Agtpre.Nomusu@vbox.tp
mail: anomusu
initials: A. N.

dn: uid=vaterre,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Vac.Aterre
sn: Aterre
givenName: Vac
uid: vaterre
uidNumber: 1002
gidNumber: 300
homeDirectory: /nfs/home/vaterre
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Vac.Aterre@vbox.tp
mail: vaterre
initials: V. A.

dn: uid=zbebert,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Zino.Bebert
sn: Bebert
givenName: Zino
uid: zbebert
uidNumber: 1003
gidNumber: 300
homeDirectory: /nfs/home/zbebert
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Zino.Bebert@vbox.tp
mail: zbebert
initials: Z. B.

dn: uid=jbond,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: James.Bond
sn: Bond
givenName: James
uid: jbond
uidNumber: 1004
gidNumber: 300
homeDirectory: /nfs/home/jbond
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: James.Bond@vbox.tp
mail: jbond
initials: J. B.

dn: uid=cboukan,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Cannotte.Boukan
sn: Boukan
givenName: Cannotte
uid: cboukan
uidNumber: 1005
gidNumber: 300
homeDirectory: /nfs/home/cboukan
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Cannotte.Boukan@vbox.tp
mail: cboukan
initials: C. B.

dn: uid=cchanteu,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Charme.Chanteur
sn: Chanteur
givenName: Charme
uid: cchanteu
uidNumber: 1006
gidNumber: 300
homeDirectory: /nfs/home/cchanteu
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Charme.Chanteur@vbox.tp
mail: cchanteu
initials: C. C.

dn: uid=dcivet,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: D'anguilles.Civet
sn: Civet
givenName: D'anguilles
uid: dcivet
uidNumber: 1007
gidNumber: 300
homeDirectory: /nfs/home/dcivet
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: D'anguilles.Civet@vbox.tp
mail: dcivet
initials: D. C.

dn: uid=jdarque,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Jeanne.Darque
sn: Darque
givenName: Jeanne
uid: jdarque
uidNumber: 1008
gidNumber: 300
homeDirectory: /nfs/home/jdarque
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Jeanne.Darque@vbox.tp
mail: jdarque
initials: J. D.

dn: uid=jdinne,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: James.Dinne
sn: Dinne
givenName: James
uid: jdinne
uidNumber: 1009
gidNumber: 300
homeDirectory: /nfs/home/jdinne
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: James.Dinne@vbox.tp
mail: jdinne
initials: J. D.

dn: uid=hdetour,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Henriette.Detour
sn: Dumans
givenName: Henriette
uid: hdetour
uidNumber: 1010
gidNumber: 300
homeDirectory: /nfs/home/hdetour
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Henriette.Detour@vbox.tp
mail: hdetour
initials: H. D.

dn: uid=hdumans,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Henriette.Dumans
sn: Dumans
givenName: Henriette
uid: hdumans
uidNumber: 1011
gidNumber: 300
homeDirectory: /nfs/home/hdumans
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Henriette.Dumans@vbox.tp
mail: hdumans
initials: H. D.

dn: uid=hdupanni,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Hans.Dupannier
sn: Dupannier
givenName: Hans
uid: hdupanni
uidNumber: 1012
gidNumber: 300
homeDirectory: /nfs/home/hdupanni
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Hans.Dupannier@vbox.tp
mail: hdupanni
initials: H. D.

dn: uid=rdupin,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Roi.Dupin
sn: Dupin
givenName: Roi
uid: rdupin
uidNumber: 1013
gidNumber: 300
homeDirectory: /nfs/home/rdupin
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Roi.Dupin@vbox.tp
mail: rdupin
initials: R. D.

dn: uid=celpere,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Cecile.Elpere
sn: Elmaquille
givenName: Cecile
uid: celpere
uidNumber: 1014
gidNumber: 300
homeDirectory: /nfs/home/celpere
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Cecile.Elpere@vbox.tp
mail: celpere
initials: C. E.

dn: uid=menc-bou,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Monnaie.Enc-bourse
sn: Enc-bourse
givenName: Monnaie
uid: menc-bou
uidNumber: 1015
gidNumber: 300
homeDirectory: /nfs/home/menc-bou
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Monnaie.Enc-bourse@vbox.tp
mail: menc-bou
initials: M. E.

dn: uid=oety,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Olive.Ety
sn: Ety
givenName: Olive
uid: oety
uidNumber: 1016
gidNumber: 300
homeDirectory: /nfs/home/oety
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Olive.Ety@vbox.tp
mail: oety
initials: O. E.

dn: uid=afonctio,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Arcive.Fonction
sn: Fonction
givenName: Arcive
uid: afonctio
uidNumber: 1017
gidNumber: 300
homeDirectory: /nfs/home/afonctio
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Arcive.Fonction@vbox.tp
mail: afonctio
initials: A. F.

dn: uid=egamelle,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Etbidon.Gamelle
sn: Gamelle
givenName: Etbidon
uid: egamelle
uidNumber: 1018
gidNumber: 300
homeDirectory: /nfs/home/egamelle
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Etbidon.Gamelle@vbox.tp
mail: egamelle
initials: E. G.

dn: uid=mguide,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Moy.Guide
sn: Guide
givenName: Moy
uid: mguide
uidNumber: 1019
gidNumber: 300
homeDirectory: /nfs/home/mguide
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Moy.Guide@vbox.tp
mail: mguide
initials: M. G.

dn: uid=pinutile,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Present.Inutile
sn: Inutile
givenName: Present
uid: pinutile
uidNumber: 1020
gidNumber: 300
homeDirectory: /nfs/home/pinutile
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Present.Inutile@vbox.tp
mail: pinutile
initials: P. I.

dn: uid=djolivet,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Dominique.Jolivet
sn: Jolivet
givenName: Dominique
uid: djolivet
uidNumber: 1021
gidNumber: 300
homeDirectory: /nfs/home/djolivet
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Dominique.Jolivet@vbox.tp
mail: djolivet
initials: D. J.

dn: uid=ljuly,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Larousse.July
sn: July
givenName: Larousse
uid: ljuly
uidNumber: 1022
gidNumber: 300
homeDirectory: /nfs/home/ljuly
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Larousse.July@vbox.tp
mail: ljuly
initials: L. J.

dn: uid=rmanapan,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Roche.Manapany
sn: Manapany
givenName: Roche
uid: rmanapan
uidNumber: 1023
gidNumber: 300
homeDirectory: /nfs/home/rmanapan
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Roche.Manapany@vbox.tp
mail: rmanapan
initials: R. M.

dn: uid=tnounou,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Tata.Nounou
sn: Nounou
givenName: Tata
uid: tnounou
uidNumber: 1024
gidNumber: 300
homeDirectory: /nfs/home/tnounou
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Tata.Nounou@vbox.tp
mail: tnounou
initials: T. N.

dn: uid=emieut,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Eva.Mieut
sn: Pabien
givenName: Eva
uid: emieut
uidNumber: 1025
gidNumber: 300
homeDirectory: /nfs/home/emieut
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Eva.Mieut@vbox.tp
mail: emieut
initials: E. M.

dn: uid=apeche,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Augros.Peche
sn: Peche
givenName: Augros
uid: apeche
uidNumber: 1026
gidNumber: 300
homeDirectory: /nfs/home/apeche
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Augros.Peche@vbox.tp
mail: apeche
initials: A. P.

dn: uid=gplumier,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Gomme.Plumier
sn: Plumier
givenName: Gomme
uid: gplumier
uidNumber: 1027
gidNumber: 300
homeDirectory: /nfs/home/gplumier
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Gomme.Plumier@vbox.tp
mail: gplumier
initials: G. P.

dn: uid=rprecieu,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Ridicule.Precieuse
sn: Precieuse
givenName: Ridicule
uid: rprecieu
uidNumber: 1028
gidNumber: 300
homeDirectory: /nfs/home/rprecieu
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Ridicule.Precieuse@vbox.tp
mail: rprecieu
initials: R. P.

dn: uid=cqualif,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Contrat.Qualif
sn: Qualif
givenName: Contrat
uid: cqualif
uidNumber: 1029
gidNumber: 300
homeDirectory: /nfs/home/cqualif
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Contrat.Qualif@vbox.tp
mail: cqualif
initials: C. Q.

dn: uid=nlavache,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Normande.Lavache
sn: Quirit
givenName: Normande
uid: nlavache
uidNumber: 1030
gidNumber: 300
homeDirectory: /nfs/home/nlavache
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Normande.Lavache@vbox.tp
mail: nlavache
initials: N. L.

dn: uid=cmedaill,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Capus.Medaille
sn: Recompense
givenName: Capus
uid: cmedaill
uidNumber: 1031
gidNumber: 300
homeDirectory: /nfs/home/cmedaill
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Capus.Medaille@vbox.tp
mail: cmedaill
initials: C. M.

dn: uid=preveren,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Pere.Reverend
sn: Reverend
givenName: Pere
uid: preveren
uidNumber: 1032
gidNumber: 300
homeDirectory: /nfs/home/preveren
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Pere.Reverend@vbox.tp
mail: preveren
initials: P. R.

dn: uid=tpicador,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Torero.Picador
sn: Spania
givenName: Torero
uid: tpicador
uidNumber: 1033
gidNumber: 300
homeDirectory: /nfs/home/tpicador
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Torero.Picador@vbox.tp
mail: tpicador
initials: T. P.

dn: uid=stempora,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Sandrine.Temporaire
sn: Temporaire
givenName: Sandrine
uid: stempora
uidNumber: 1034
gidNumber: 300
homeDirectory: /nfs/home/stempora
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Sandrine.Temporaire@vbox.tp
mail: stempora
initials: S. T.

dn: uid=ptemps,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Partiel.Temps
sn: Temps
givenName: Partiel
uid: ptemps
uidNumber: 1035
gidNumber: 300
homeDirectory: /nfs/home/ptemps
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Partiel.Temps@vbox.tp
mail: ptemps
initials: P. T.

dn: uid=aterrieu,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Alex.Terrieur
sn: Terrieur
givenName: Alex
uid: aterrieu
uidNumber: 1036
gidNumber: 300
homeDirectory: /nfs/home/aterrieu
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Alex.Terrieur@vbox.tp
mail: aterrieu
initials: A. T.

dn: uid=mtilleul,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Medor.Tilleul
sn: Tilleul
givenName: Medor
uid: mtilleul
uidNumber: 1037
gidNumber: 300
homeDirectory: /nfs/home/mtilleul
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Medor.Tilleul@vbox.tp
mail: mtilleul
initials: M. T.

dn: uid=dcoudur,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Drole de.Coudur
sn: Tronche
givenName: Drole de
uid: dcoudur
uidNumber: 1038
gidNumber: 300
homeDirectory: /nfs/home/dcoudur
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Drole de.Coudur@vbox.tp
mail: dcoudur
initials: D. C.

dn: uid=mzethofr,ou=people,dc=vbox,dc=tp
objectClass: inetOrgPerson
objectClass: posixAccount
objectClass: shadowAccount
cn: Melanie.Zethofrais
sn: Zethofrais
givenName: Melanie
uid: mzethofr
uidNumber: 1039
gidNumber: 300
homeDirectory: /nfs/home/mzethofr
loginShell: /bin/bash
userPassword: {SSHA}6gHTLCHTwZjOv/HjT//pTq94ba1HyQq1
mail: Melanie.Zethofrais@vbox.tp
mail: mzethofr
initials: M. Z.


EOF


ldapadd -x -H ldap://127.0.0.1 -D "cn=admin,dc=vbox,dc=tp" -w $RootPW -f /tmp/users.ldif


cat <<EOF > /tmp/groups.ldif
dn: cn=vbox-users,ou=groups,dc=vbox,dc=tp
objectClass: posixGroup
gidNumber: 300
cn: vbox-users

dn: cn=secretariat,ou=groups,dc=vbox,dc=tp
objectClass: groupOfNames
cn: secretariat
description: Le secretariat
member: uid=anomusu,ou=people,dc=vbox,dc=tp
member: uid=djolivet,ou=people,dc=vbox,dc=tp

dn: cn=comptabilite,ou=groups,dc=vbox,dc=tp
objectClass: groupOfNames
cn: comptabilite
description: La comptabilite
member: uid=vaterre,ou=people,dc=vbox,dc=tp
member: uid=zbebert,ou=people,dc=vbox,dc=tp
member: uid=jbond,ou=people,dc=vbox,dc=tp

dn: cn=equipe1,ou=groups,dc=vbox,dc=tp
objectClass: groupOfNames
cn: equipe1
description: Equipe numero 1
member: uid=cboukan,ou=people,dc=vbox,dc=tp
member: uid=cchanteu,ou=people,dc=vbox,dc=tp
member: uid=dcivet,ou=people,dc=vbox,dc=tp
member: uid=jdarque,ou=people,dc=vbox,dc=tp
member: uid=jdinne,ou=people,dc=vbox,dc=tp
member: uid=hdetour,ou=people,dc=vbox,dc=tp
member: uid=hdumans,ou=people,dc=vbox,dc=tp
member: uid=hdupanni,ou=people,dc=vbox,dc=tp
member: uid=rdupin,ou=people,dc=vbox,dc=tp
member: uid=celpere,ou=people,dc=vbox,dc=tp
member: uid=menc-bou,ou=people,dc=vbox,dc=tp
member: uid=oety,ou=people,dc=vbox,dc=tp
member: uid=afonctio,ou=people,dc=vbox,dc=tp

dn: cn=equipe2,ou=groups,dc=vbox,dc=tp
objectClass: groupOfNames
cn: equipe2
description: Equipe numero 2
member: uid=egamelle,ou=people,dc=vbox,dc=tp
member: uid=mguide,ou=people,dc=vbox,dc=tp
member: uid=pinutile,ou=people,dc=vbox,dc=tp
member: uid=ljuly,ou=people,dc=vbox,dc=tp
member: uid=rmanapan,ou=people,dc=vbox,dc=tp
member: uid=tnounou,ou=people,dc=vbox,dc=tp
member: uid=emieut,ou=people,dc=vbox,dc=tp
member: uid=apeche,ou=people,dc=vbox,dc=tp
member: uid=gplumier,ou=people,dc=vbox,dc=tp

dn: cn=equipe3,ou=groups,dc=vbox,dc=tp
objectClass: groupOfNames
cn: equipe3
description: Equipe numero 3
member: uid=rprecieu,ou=people,dc=vbox,dc=tp
member: uid=cqualif,ou=people,dc=vbox,dc=tp
member: uid=nlavache,ou=people,dc=vbox,dc=tp
member: uid=cmedaill,ou=people,dc=vbox,dc=tp
member: uid=preveren,ou=people,dc=vbox,dc=tp
member: uid=tpicador,ou=people,dc=vbox,dc=tp
member: uid=stempora,ou=people,dc=vbox,dc=tp
member: uid=ptemps,ou=people,dc=vbox,dc=tp
member: uid=aterrieu,ou=people,dc=vbox,dc=tp
member: uid=mtilleul,ou=people,dc=vbox,dc=tp
member: uid=dcoudur,ou=people,dc=vbox,dc=tp
member: uid=mzethofr,ou=people,dc=vbox,dc=tp


EOF


ldapadd -x -H ldap://127.0.0.1 -D "cn=admin,dc=vbox,dc=tp" -w $RootPW -f /tmp/groups.ldif